Fernando Daciuk (@fdaciuk) header
Fernando Daciuk (@fdaciuk) profile picture

➤ 🦋 @ https://nitter.cf/t.co/Oa8F5pYnJH ➤ Teacher @ https://nitter.cf/t.co/2e25Ftid9w ➤ Live Coder @ https://nitter.cf/t.co/eHhX9yNh5Y ➤ Making devs' lives easier @ https://nitter.cf/t.co/D9ior8Nrlo ➤ Rocket League enthusiast

Brazil
Joined November 2009
Photo by Fernando Daciuk (@fdaciuk)Photo by Fernando Daciuk (@fdaciuk)Photo by Fernando Daciuk (@fdaciuk)Photo by Fernando Daciuk (@fdaciuk)Photo by Fernando Daciuk (@fdaciuk)Photo by Fernando Daciuk (@fdaciuk)Photo by Fernando Daciuk (@fdaciuk)Photo by Fernando Daciuk (@fdaciuk)Photo by Fernando Daciuk (@fdaciuk)Photo by Fernando Daciuk (@fdaciuk)
Fernando Daciuk retweeted
Bun AOT is designed to run existing Bun & Node apps without code changes eval, new Function & node:vm still work, along with all the Bun & Node APIs in Bun I expect the performance, memory, and security improvements to eventually make AOT the default for server-side JS
Bun AOT is merged. Still more to fix/fuzz before its release-able
42
14
4
597
23,760
Fernando Daciuk retweeted
Bun AOT also introduces `--trim` which deletes unused parts of Bun from the compiled binary On macOS, a binary that uses Bun.serve’s HTTP server goes from 89 MB to 25 MB
60
47
18
1,484
111,363
Fernando Daciuk retweeted
what if you could pass a TypeScript type to JSON.parse and it validates the input at runtime?
147
34
21
1,815
189,255
Fernando Daciuk retweeted
Replying to @rescriptlang
I had pretty much stopped reviewing ReScript PRs. Just rubber stamping most times. Now we can review again, at a higher level. There are a dozen PRs per day, most correct. Lots of issues can be caught by semantic drift analysis later on. So the cost benefit of detailed reviews had shifted. But that can only go so far before things go out of hand. Now aiming for a new balance.
4
6
343
Fernando Daciuk retweeted
Development of ReScript V13 is going well. We now have ways to make sense of a PR diff much quicker. We call it "semantic diff". Example attached.
1
9
67
2,266
Fernando Daciuk retweeted
Bun v1.4.4 - Fixes 271 issues, addressing 544 👍 - `bun fmt` is a fast Prettier-compatible code formatter - `bun check` gets 1.4x - 7.8x faster - New in Bun.SQL & WebSocket - Security fixes, including for Brotli, TLS certs, HTTP/3, and more bun.com/blog/bun-v1.4.4
48
76
26
1,296
92,603
Fernando Daciuk retweeted
In the next version of Bun bun lint is a 26x faster ESLint-compatible linter with over 1,000 builtin rules - reads eslint & oxlint configs.
56
60
18
1,155
98,601
Fernando Daciuk retweeted
In the next version of Bun `bun fmt` is a 320x faster Prettier alternative Passes 99% of Prettier's test suite & supports 20 languages
111
128
61
2,204
145,903
Fernando Daciuk retweeted
Bun v1.4.3 - Fixes 166 issues (addressing 122 👍) - `bun check`: fast TypeScript type-checker builtin to Bun - 67% lower idle CPU in servers - `Bun.FetchSession` - Faster JSON.parse - Node.js compatibility fixes & lots of bugfixes bun.com/blog/bun-v1.4.3
21
58
12
1,051
56,314
Fernando Daciuk retweeted
24
22
3
1,207
26,023
Fernando Daciuk retweeted
Today, Bun is a: - Node-compatible JavaScript runtime - npm-compatible package manager - jest-compatible test runner - esbuild-compatible bundler Next week, Bun gets 3 more tools on that list.
Bun v1.5 ships on Wednesday
63
34
5
1,828
81,422
Fernando Daciuk retweeted
介绍比Jev快50倍,在你设备上跑的laya-mlx! 只在你的设备上占用最高1G内存 Laya是一个开源的类似于Jev的,基于文本输出概率的分类系统 我将其移植到MLX,并且做了一些性能优化! 视频中就是这个模型在我的本地M3Max上玩贪吃蛇 这个模型能够以每秒决策60次的速度玩贪吃蛇! github.com/mizorewww/laya-ml…
295
1,206
476
14,049
4,314,904
Fernando Daciuk retweeted
ReScript 13.0.0-alpha.6 is out! I contributed parser improvements that cut parsing time by ~5% on real code (~10% in some synthetic benchmarks). Long-awaited source map support is here too. Give this pre-release a try! github.com/rescript-lang/res…
7
32
1,324
Fernando Daciuk retweeted
Was tired of the void, decided to introduce a better map for it. Check it out on car-soccer.com (yes, it runs in the browser). I spent a long time tweaking the physics and camera to capture the authentic Rocket League feel. Freestylers and SSLs have already played it, and they loved it! Try it and let me know what you think!
99
64
41
1,138
702,875
Fernando Daciuk retweeted
Tip: Claude Code has several skill-cleanup commands. Each answers a different question. /skill-doctor → which skills you use /skills, then t → what each costs /doctor → fixes setup + CLAUDE.md debt /context → what's in the window now /usage → what burns your limits
60
66
7
747
47,597
Fernando Daciuk retweeted
Bun v1.4.2 - Fixes 5 issues - CMYK & YCCK JPEG decoding now supported in Bun.Image - Response & Request .json() show a better error - Fix bundler regression impacting Elysia - Fix AsyncLocalStorage leak - JavaScriptCore upgrade bun.com/blog/bun-v1.4.2
28
21
9
666
31,140
Fernando Daciuk retweeted
Bun v1.4.1 - Fixes 202 issues, addressing 236 👍 - Reduced idle memory usage - HTTP/2 in Bun.serve() - Big upgrade for Bun's bundler - bun build --compile executables load faster & we shrunk bytecode - Bun starts 1ms faster bun.com/blog/bun-v1.4.1
35
50
12
910
41,565
Fernando Daciuk retweeted
Bun v1.4.1 is a big upgrade to Bun’s bundler. On a 200-route React app over simulated 4G, navigating between routes is 38% faster than Bun v1.4.0, and 10% faster than Vite v8.2.2.
18
24
3
687
41,073
Fernando Daciuk retweeted
In the next version of Bun Bun's bundler gets smarter about tree-shaking ESM that uses `export * as ns` syntax
9
10
2
416
19,013
Fernando Daciuk retweeted
In the next version of Bun `bun build --splitting` injects `<link rel="modulepreload">`, helping webpages load faster by reducing network waterfalls
8
24
849
46,444